"""
This type stub file was generated by pyright.
"""

from ._common import *

def remove(src, new_file=...): # -> None:
    """
    py:function:: piexif.remove(filename)

    Remove exif from JPEG.

    :param str filename: JPEG
    """
    ...
