"""
This type stub file was generated by pyright.
"""

def split_into_segments(data): # -> list[bytes]:
    """Slices JPEG meta data into a list from JPEG binary data.
    """
    ...

def read_exif_from_file(filename): # -> bytes | None:
    """Slices JPEG meta data into a list from JPEG binary data.
    """
    ...

def get_exif_seg(segments): # -> None:
    """Returns Exif from JPEG meta data list
    """
    ...

def merge_segments(segments, exif=...): # -> bytes:
    """Merges Exif with APP0 and APP1 manipulations.
    """
    ...
