"""
This type stub file was generated by pyright.
"""

def split(data): # -> list[Any]:
    ...

def merge_chunks(chunks): # -> bytes:
    ...

def set_vp8x(chunks):
    ...

def get_file_header(chunks): # -> bytes:
    ...

def get_exif(data): # -> None:
    ...

def insert_exif_into_chunks(chunks, exif_bytes):
    ...

def insert(webp_bytes, exif_bytes): # -> bytes:
    ...

def remove(webp_bytes): # -> bytes:
    ...
