"""
This type stub file was generated by pyright.
"""

from ._common import *

def insert(exif, image, new_file=...): # -> None:
    """
    py:function:: piexif.insert(exif_bytes, filename)

    Insert exif into JPEG.

    :param bytes exif_bytes: Exif as bytes
    :param str filename: JPEG
    """
    ...
